Struct RouterContext
pub struct RouterContext { /* private fields */ }router only.Expand description
A collection of router data that manages all routing functionality.
Implementations
impl RouterContext
impl RouterContext
pub fn create_global<R>(cfg: RouterConfig<R>) -> RouterContextwhere
R: Routable + 'static,
pub fn create_global<R>(cfg: RouterConfig<R>) -> RouterContextwhere
R: Routable + 'static,
Create a global RouterContext that lives for the entire application lifetime.
This is useful for sharing router state across multiple windows.
This is not a hook, do not use it inside components like you would use_route.
You would usually want to call this in your main function, not anywhere else.
Example
fn main() {
let router = RouterContext::create_global::<Route>(RouterConfig::default());
launch(
LaunchConfig::new()
.with_window(WindowConfig::new_app(MyApp { router })),
);
}pub fn try_get() -> Option<RouterContext>
pub fn get() -> RouterContext
pub fn can_go_back(&self) -> bool
pub fn can_go_back(&self) -> bool
Check whether there is a previous page to navigate back to.
pub fn can_go_forward(&self) -> bool
pub fn can_go_forward(&self) -> bool
Check whether there is a future page to navigate forward to.
pub fn go_back(&self)
pub fn go_back(&self)
Go back to the previous location.
Will fail silently if there is no previous location to go to.
pub fn go_forward(&self)
pub fn go_forward(&self)
Go back to the next location.
Will fail silently if there is no next location to go to.
pub fn push(
&self,
target: impl Into<NavigationTarget>,
) -> Option<ExternalNavigationFailure>
pub fn push( &self, target: impl Into<NavigationTarget>, ) -> Option<ExternalNavigationFailure>
Push a new location.
The previous location will be available to go back to.
pub fn replace(
&self,
target: impl Into<NavigationTarget>,
) -> Option<ExternalNavigationFailure>
pub fn replace( &self, target: impl Into<NavigationTarget>, ) -> Option<ExternalNavigationFailure>
Replace the current location.
The previous location will not be available to go back to.
pub fn full_route_string(&self) -> String
pub fn full_route_string(&self) -> String
The full route that is currently active. If this is called from inside a child router, this will always return the parent’s view of the route.
pub fn site_map(&self) -> &'static [SiteMapSegment]
pub fn site_map(&self) -> &'static [SiteMapSegment]
Get the site map of the router.